@@ -1,15 +1,20 @@
 import pandas
 import re
 
-def extract_postcode_from_address(addr: str) -> tuple[str, str]:
-  postcode_pattern = re.compile(r'[A-Za-z]{1,2}\d[A-Za-z\d]?\s?\d[A-Za-z]{2}')
-  match = postcode_pattern.search(addr)
-  postcode = match.group()
-  new_addr = addr.replace(postcode, '').rstrip(', \n\t')
-  return new_addr, postcode
+def extract_postcode_from_address(addr: str, raiseFailures: bool = True) -> tuple[str, str]:
+  try:
+    postcode_pattern = re.compile(r'[A-Za-z]{1,2}\d[A-Za-z\d]?\s?\d[A-Za-z]{2}')
+    match = postcode_pattern.search(addr)
+    postcode = match.group()
+    new_addr = addr.replace(postcode, '').rstrip(', \n\t')
+    return new_addr, postcode
+  except Exception as e:
+    if raiseFailures:
+      raise Exception(f"unable to extract postcode from address '{addr}', {e}")
+    return addr, None
 
 def extract_postcode_from_address_series(s: pandas.Series) -> tuple[str, str]:
-  return extract_postcode_from_address(s['address_1'])
+  return pandas.Series(extract_postcode_from_address(s['address_1'], False))
 
 def break_out_individuals_cpl(
     df: pandas.DataFrame,
@@ -78,7 +83,7 @@ def break_out_individuals_cpl(
 
   # extract postcode from address if it isn't separate
   if 'postcode' not in combined_df.columns:
-    combined_df[['address_1', 'postcode']] = combined_df.apply(extract_postcode_from_address_series, axis=1)
+    combined_df[['address_1', 'postcode']] = combined_df.apply(extract_postcode_from_address_series, axis=1).apply(pandas.Series)
 
   # ensure the required columns
   required_subset = ['forename', 'surname', 'address_1', 'postcode']
